@@ -2,12 +2,12 @@ from django.contrib import admin
 from django_kubernetes_manager.models import (TargetCluster,
     KubernetesContainer, KubernetesPodTemplate, KubernetesJob,
     KubernetesDeployment, KubernetesService, KubernetesIngress,
-    KubernetesNamespace)
+    KubernetesNamespace, KubernetesConfigMap)
 
 models = [TargetCluster,
     KubernetesContainer, KubernetesPodTemplate, KubernetesJob,
     KubernetesDeployment, KubernetesService, KubernetesIngress,
-    KubernetesNamespace]
+    KubernetesNamespace, KubernetesConfigMap]
 
 for model in models:
     admin.site.register(model)
