@@ -2,5 +2,6 @@ from .base import (KubernetesContainer, KubernetesDeployment,
                    KubernetesIngress, KubernetesJob, KubernetesNamespace,
                    KubernetesPodTemplate, KubernetesService, KubernetesVolume,
                    KubernetesVolumeMount, KubernetesNamespace, KubernetesBase,
-                   KubernetesMetadataObjBase, KubernetesNetworkingBase)
+                   KubernetesMetadataObjBase, KubernetesNetworkingBase,
+                   KubernetesConfigMap)
 from .target_cluster import TargetCluster
